@@ -141,7 +141,7 @@ www.linktv.org videos (L<StreamFinder::LinkTV>),
 onlineradiobox.com radio stations (L<StreamFinder::OnlineRadiobox>), 
 odysee.com videos (L<StreamFinder::Odysee>), 
 podbean.com podcasts (L<StreamFinder::Podbean>), 
-podcastaddict.com podcasts (L<StreamFinder::PodcastAddict>), 
+podcastaddict.com podcasts (L<StreamFinder::PodcastAddict>) (DEPRECIATED), 
 podchaser.com podcasts (L<StreamFinder::Podchaser>), 
 radio.net radio stations (L<StreamFinder::RadioNet>), 
 rcast.net radio stations (L<StreamFinder::Rcast>), 
@@ -149,6 +149,7 @@ rumble.com videos (L<StreamFinder::Rumble>),
 sermonaudio.com sermons: audio and video (L<StreamFinder::SermonAudio>), 
 soundcloud.com (non-paywalled) songs (L<StreamFinder::SoundCloud>), 
 spreaker.com podcasts (L<StreamFinder::Spreaker>), 
+subsplash.com podcasts (L<StreamFinder::Subsplash>) (EXPERIMENTAL), 
 tunein.com (non-paywalled) radio stations and podcasts 
 (L<StreamFinder::Tunein>), vimeo.com videos (L<StreamFinder::Vimeo>), 
 youtube.com, et. al and other sites that youtube-dl supports 
@@ -536,7 +537,7 @@ use strict;
 use warnings;
 use vars qw(@ISA @EXPORT $VERSION);
 
-our $VERSION = '2.18';
+our $VERSION = '2.19';
 our $DEBUG = 0;
 
 require Exporter;
@@ -545,7 +546,7 @@ require Exporter;
 @EXPORT = qw();
 my @supported_mods = (qw(Anystream Apple Bitchute Blogger BrandNewTube Brighteon Castbox  
 		Google IHeartRadio InternetRadio Odysee OnlineRadiobox Podbean PodcastAddict Podchaser 
-		RadioNet Rcast Rumble SermonAudio SoundCloud	Spreaker	Tunein Vimeo Youtube LinkTV Zeno));
+		RadioNet Rcast Rumble SermonAudio SoundCloud	Spreaker	Tunein Vimeo Youtube LinkTV Zeno Subsplash));
 
 my %useit;
 
@@ -651,6 +652,9 @@ sub new
 	} elsif ($url =~ m#\bzeno\.# && $useit{'Zeno'}) {
 		eval { require 'StreamFinder/Zeno.pm'; $haveit = 1; };
 		return new StreamFinder::Zeno($url, @args)  if ($haveit);
+	} elsif ($url =~ m#\bsubsplash\.# && $useit{'Subsplash'}) {
+		eval { require 'StreamFinder/Subsplash.pm'; $haveit = 1; };
+		return new StreamFinder::Subsplash($url, @args)  if ($haveit);
 	} elsif ($useit{'Youtube'}) {  #DEFAULT TO youtube-dl SINCE SO MANY URLS ARE HANDLED THERE NOW.
 		eval { require 'StreamFinder/Youtube.pm'; $haveit = 1; };
 		if ($haveit) {
